@@ -155,7 +155,7 @@ sub requires {
 ##	'SOAP::Lite' => 0,
 	'Scalar::Util' => 1.01,	# Not in Perl 5.6
 	'URI::Escape' => 0,
-	'XML::DoubleEncodedEntities' => 1.0,
+	# 'XML::DoubleEncodedEntities' => 1.0,
 	constant	=> 0,
 	strict		=> 0,
 	warnings	=> 0,
@@ -347,7 +347,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2021 by Thomas R. Wyant, III
+Copyright (C) 2010-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
