@@ -99,9 +99,17 @@ use LWP::Protocol;
 use HTTP::Request::Common qw{POST};
 use Scalar::Util 1.01 qw{looks_like_number};
 use URI::Escape ();
-use XML::DoubleEncodedEntities;
+# use XML::DoubleEncodedEntities;
 # use Astro::SIMBAD::Client::WSQueryInterfaceService;
 
+use constant HAVE_DOUBLE_ENCODED	=> do {
+    local $@ = undef;
+    eval {	## no critic (RequireCheckingReturnValueOfEval)
+	require XML::DoubleEncodedEntities;
+	1;
+    };
+};
+
 use constant ARRAY_REF	=> ref [];
 use constant CODE_REF	=> ref sub {};
 
@@ -118,7 +126,7 @@ BEGIN {
 	|| sub { return $_[0] };
 }
 
-our $VERSION = '0.046';
+our $VERSION = '0.047';
 
 our @CARP_NOT = qw{Astro::SIMBAD::Client::WSQueryInterfaceService};
 
@@ -676,13 +684,14 @@ EOD
 	SOAP::Lite->import (+trace => $debug ? 'all' : '-all');
 	$self->_delay ();
 ##	$debug and SOAP::Trace->import ('all');
-	my $resp = Astro::SIMBAD::Client::WSQueryInterfaceService->$method(
+	my $rslt = Astro::SIMBAD::Client::WSQueryInterfaceService->$method(
 	    $self, @args);
-	return unless defined $resp;
-	$resp = XML::DoubleEncodedEntities::decode ($resp);
-	return wantarray ? ($parser->($resp)) : [$parser->($resp)]
+	return unless defined $rslt;
+	HAVE_DOUBLE_ENCODED
+	    and $rslt = XML::DoubleEncodedEntities::decode ($rslt);
+	return wantarray ? ($parser->($rslt)) : [$parser->($rslt)]
 	    if $parser;
-	return $resp;
+	return $rslt;
     }
 
 }	# End local symbol block.
@@ -867,7 +876,8 @@ sub script {
 	$debug
 	    and warn "Debug - result:\n$rslt ";
 
-	$rslt = XML::DoubleEncodedEntities::decode( $rslt );
+	HAVE_DOUBLE_ENCODED
+	    and $rslt = XML::DoubleEncodedEntities::decode ($rslt);
 	if ( my $parser = $self->_get_parser( $arg{parser} ) ) {
 	    $debug
 		and warn "Debug - Parser $arg{parser}";
@@ -1108,16 +1118,19 @@ eod
 	}
 	my $resp = $self->_retrieve( "simbad/sim-$query", \%args );
 
-	$resp = XML::DoubleEncodedEntities::decode ($resp->content);
+	my $rslt = $resp->content();
+
+	HAVE_DOUBLE_ENCODED
+	    and $rslt = XML::DoubleEncodedEntities::decode( $rslt );
 
 	my $parser;
 	if (my $type = $type_unmap{$args{'output.format'}}) {
 	    $parser = $self->_get_parser ($type);
-	    return wantarray ? ($parser->($resp)) : [$parser->($resp)]
+	    return wantarray ? ($parser->($rslt)) : [$parser->($rslt)]
 		if $parser;
 	}
 
-	return $resp;
+	return $rslt;
     }
 
 }	# End local symbol block.
@@ -1704,7 +1717,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2021 by Thomas R. Wyant, III
+Copyright (C) 2005-2023 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
